@@ -71,7 +71,8 @@ class BaseBrowser(object):
         self.redirect = redirect
         self.retry_limit = 4
         self.timeout = 30
-        self._keep_alive = False  
+        self._keep_alive = False
+        self._accept_language = 'en-US,en;q=0.5'
 
         self.has_cookies = cookies
         self.use_real_cookie_file = False
@@ -79,6 +80,8 @@ class BaseBrowser(object):
         self.proxy_list = []
         self.use_proxy_dns = True
         self.cookie_file_path = ""
+        self.last_url = ''
+        self.auto_referer = True
         
         self.current_proxy = ''
         if mobile:
@@ -95,9 +98,9 @@ class BaseBrowser(object):
             #self.tempfile, self.tempfilename = tempfile.TemporaryFile()
         self.headers = {
             'Accept': 'text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,image/png,*/*;q=0.5',
-            'Accept-Language': 'en-US,en;q=0.5',
+            'Accept-Language': self._accept_language,
             'Accept-Encoding': 'gzip, deflate',
-            'Accept-Charset': 'ISO-8859-1,utf-8;q=0.7,*;q=0.3',
+            'Accept-Charset': 'utf-8,ISO-8859-1;q=0.7,*;q=0.3',
         }
 
     def __del__(self):
@@ -142,9 +145,20 @@ class BaseBrowser(object):
 
     def _get_keep_alive(self): 
         return self._keep_alive
-
     keep_alive = property(_get_keep_alive, _set_keep_alive)
 
+    def _set_accept_language(self, value):
+        """
+        set accept language
+        """
+        self.headers['Accept-Language'] = value  
+        #raise Exception("Invalid Keep Alive Value")
+        self._accept_language = value
+
+    def _get_accept_language(self): 
+        return self._accept_language
+    accept_language = property(_get_accept_language, _set_accept_language)  
+
     def enable_keep_alive(self):
         keep_alive = True
 
