@@ -72,9 +72,10 @@ class Browser(BaseBrowser): #CURL
             self.c.setopt(pycurl.MAXREDIRS, 0)  
 
         self.c.setopt(pycurl.USERAGENT, self.user_agent)
+        self.c.setopt(pycurl.NOBODY, False)  
         if hasattr(self, 'veryverbose') and self.veryverbose:
             self.c.setopt(pycurl.DEBUGFUNCTION, self.debug_msg)
-            self.c.setopt(pycurl.VERBOSE, 1)  
+            #self.c.setopt(pycurl.VERBOSE, 1)  
         self.c.setopt(pycurl.TIMEOUT, self.timeout) 
         
         request_headers = self.headers.copy()
@@ -95,15 +96,19 @@ class Browser(BaseBrowser): #CURL
             self.c.setopt(pycurl.URL, request.url.encode('utf-8') )  
         except UnicodeDecodeError:
             print "couldn't encode", request.url 
-        if request.referer != '':
+        if request.referer and request.referer != '':
             self.c.setopt(pycurl.REFERER, request.referer.encode('utf-8'))
-
+        elif request.referer == None and self.auto_referer:
+            self.c.setopt(pycurl.REFERER, self.last_url.encode('utf-8'))     
+            
         if self.has_cookies == True:
             self.c.setopt(pycurl.COOKIEFILE, self.cookie_file_path)
         if self.use_real_cookie_file: 
             self.c.setopt(pycurl.COOKIEJAR, self.cookie_file_path)
-        if request.cookies != '':
-            self.c.setopt(pycurl.COOKIE, request.cookies)
+        if isinstance(request.cookies, list) and len(request.cookies):
+            self.c.setopt(pycurl.COOKIE, '; '.join(request.cookies))
+        if request.method not in ['POST', 'GET']:
+            self.c.setopt(pycurl.CUSTOMREQUEST, request.method)
         if request.post != None:
             #print self.post
             self.c.setopt(pycurl.POST, 1);
@@ -118,7 +123,7 @@ class Browser(BaseBrowser): #CURL
             else:
                 self.c.setopt(pycurl.POSTFIELDS, request.post)
         elif request.only_head:
-            self.c.setopt(pycurl.CUSTOMREQUEST, "HEAD")
+            #self.c.setopt(pycurl.CUSTOMREQUEST, "HEAD")   #doesn't seem to be required
             self.c.setopt(pycurl.NOBODY, True) 
         else:
             self.c.setopt(pycurl.HTTPGET, 1)    
@@ -134,7 +139,7 @@ class Browser(BaseBrowser): #CURL
 
     def try_select_new_proxy(self):
         if len(self.proxy_list):
-            self.current_proxy = proxy = random.choice([k for k in self.proxy_list])  
+            self.current_proxy = random.choice([k for k in self.proxy_list])  
             if self.verbose:
                 print "new proxy", self.current_proxy
         
@@ -149,7 +154,7 @@ class Browser(BaseBrowser): #CURL
         try:
             
             if request.tries >= self.retry_limit:
-                raise BrowserError('tries exceeded')
+                raise BrowserError('tries exceeded: %s' % request.url)
             elif request.tries > 0:
                 #print "retry "  + str(tries) + " " + str(id) + " " + time.strftime("%I:%M:%S %p",time.localtime())
                 pass
@@ -177,6 +182,10 @@ class Browser(BaseBrowser): #CURL
                     self.c.setopt(pycurl.PROXYTYPE, pycurl.PROXYTYPE_SOCKS4)
                 elif self.proxy_type == "SOCKS5":
                     self.c.setopt(pycurl.PROXYTYPE, pycurl.PROXYTYPE_SOCKS5)
+                elif self.proxy_type == "HTTP":
+                    self.c.setopt(pycurl.PROXYTYPE, pycurl.PROXYTYPE_HTTP)  
+                elif self.proxy_type == "HTTP10":
+                    self.c.setopt(pycurl.PROXYTYPE, pycurl.CURLPROXY_HTTP_1_0) 
             elif request.proxy == None and self.proxies_only == True:
                 raise BrowserError('proxy required')
             
@@ -189,6 +198,7 @@ class Browser(BaseBrowser): #CURL
             b_response.response_URI = self.c.getinfo(pycurl.EFFECTIVE_URL)
             b_response.redirect_count = self.c.getinfo(pycurl.REDIRECT_COUNT)
             b_response.redirect_url = self.c.getinfo(pycurl.REDIRECT_URL)
+            self.last_url = b_response.response_url
 
             b_response.time_info = dict(
                 namelookup=self.c.getinfo(pycurl.NAMELOOKUP_TIME),
@@ -206,7 +216,6 @@ class Browser(BaseBrowser): #CURL
                 b_response = self.request(request)  
             return b_response
         except pycurl.error, e:
-
             #TODO add retry code here
             b_response.error_msg ="raised a \
                             pycurl.error " + str(e.args)
@@ -217,12 +226,16 @@ class Browser(BaseBrowser): #CURL
             elif e[1].find('request rejected or failed') != -1:
                 self.try_select_new_proxy()
                 b_response = self.request(request) 
+            elif e[1].find("couldn't connect to host") != -1:
+                raise BrowserError(e[1] + " " + request.url)        
             elif e[1].find('Empty reply from server') != -1:
                 self.try_select_new_proxy()
                 b_response = self.request(request)  
             else:
                 raise BrowserError(e[1])
                 print "pycurl error tries", request.tries, str(e.args) ,request.url, request.proxy
+        except BrowserError, e:
+            raise
         except Exception, e:
             if self.verbose:
                 exc_type, exc_value, exc_traceback = sys.exc_info()
