@@ -41,7 +41,7 @@ class Response:
 
     @property
     def content(self):
-        return self.response()  
+        return self.response  
 
     def set_data(self, code=None,
             error_code='', error_msg=''):
@@ -63,6 +63,7 @@ class Response:
                 self.headers_dict[values[0].strip()] = values[1].strip()
         self.headers = new_h
         #print self.headers
+
     def get_cookies(self):
         cookie_dict = {}
         for x in self.raw_cookies:
